abacusai.refresh_pipeline_run — AbacusAI documentation

# `abacusai.refresh_pipeline_run`

## Module Contents

### Classes

`RefreshPipelineRun` | This keeps track of the overall status of a refresh. A refresh can span multiple resources such as the creation of new dataset versions and the training of a new model version based on them.

class abacusai.refresh_pipeline_run.RefreshPipelineRun(client, refreshPipelineRunId=None, refreshPolicyId=None, createdAt=None, startedAt=None, completedAt=None, status=None, refreshType=None, datasetVersions=None, featureGroupVersion=None, modelVersions=None, predictionMetricVersions=None, deploymentVersions=None, batchPredictions=None, refreshPolicy={})

  Bases: `abacusai.return_class.AbstractApiClass`

  This keeps track of the overall status of a refresh. A refresh can span multiple resources such as the creation of new dataset versions and the training of a new model version based on them.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - refreshPipelineRunId (str) – The unique identifier for the refresh pipeline run.

    - refreshPolicyId (str) – Populated when the run was triggered by a refresh policy.

    - createdAt (str) – The time when this refresh pipeline run was created, in ISO-8601 format.

    - startedAt (str) – The time when the refresh pipeline run was started, in ISO-8601 format.

    - completedAt (str) – The time when the refresh pipeline run was completed, in ISO-8601 format.

    - status (str) – The status of the refresh pipeline run.

    - refreshType (str) – The type of refresh policy to be run.

    - datasetVersions (list[str]) – A list of dataset version IDs that this refresh pipeline run is monitoring.

    - featureGroupVersion (str) – The feature group version ID that this refresh pipeline run is monitoring.

    - modelVersions (list[str]) – A list of model version IDs that this refresh pipeline run is monitoring.

    - predictionMetricVersions (list[str]) – A list of prediction metric versions that this refresh pipeline run is monitoring.

    - deploymentVersions (list[str]) – A list of deployment version IDs that this refresh pipeline run is monitoring.

    - batchPredictions (list[str]) – A list of batch prediction IDs that this refresh pipeline run is monitoring.

    - refreshPolicy (RefreshPolicy) – The refresh policy for this refresh policy run.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  refresh()

    Calls describe and refreshes the current object’s fields

    Returns:

      The current object

    Return type:

      RefreshPipelineRun

  describe()

    Retrieve a single refresh pipeline run

    Parameters:

      refresh_pipeline_run_id (str) – Unique string identifier associated with the refresh pipeline run.

    Returns:

      A refresh pipeline run object.

    Return type:

      RefreshPipelineRun

  wait_for_complete(timeout=None)

    A waiting call until refresh pipeline run has completed.

    Parameters:

      timeout (int, optional) – The waiting time given to the call to finish, if it doesn’t finish by the allocated time, the call is said to be timed out.

  get_status()

    Gets the status of the refresh pipeline run.

    Returns:

      A string describing the status of a refresh pipeline run (pending, complete, etc.).

    Return type:

      str